==> haskell-test-framework-quickcheck2-0.3.0.5-1-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-test-framework-quickcheck2.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: test-framework-quickcheck2
version: 0.3.0.5
id: test-framework-quickcheck2-0.3.0.5-lumk0IKhGJLesx4uOHXCH
key: test-framework-quickcheck2-0.3.0.5-lumk0IKhGJLesx4uOHXCH
license: BSD-3-Clause
maintainer: Haskell Libraries <libraries@haskell.org>
author: Max Bolingbroke <batterseapower@hotmail.com>
homepage: http://haskell.github.io/test-framework/
synopsis: QuickCheck-2 support for the test-framework package.
description:
    Allows @QuickCheck-2@ properties to be used with the </package/test-framework test-framework package>.
category: Testing
abi: 93c6c2de61c8c0af063e2d8b1552871d
exposed: True
exposed-modules:
    Test.Framework.Providers.QuickCheck2
import-dirs: /usr/lib/ghc-8.4.3/site-local/test-framework-quickcheck2-0.3.0.5
library-dirs: /usr/lib/ghc-8.4.3/site-local/test-framework-quickcheck2-0.3.0.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/test-framework-quickcheck2-0.3.0.5
hs-libraries: HStest-framework-quickcheck2-0.3.0.5-lumk0IKhGJLesx4uOHXCH
depends:
    test-framework-0.8.2.0-DhLbYTIlvP2DU0cHcKcIVn
    QuickCheck-2.11.3-58QsvdIMmwDDNaUIIDmLAr base-4.11.1.0
    extensible-exceptions-0.1.1.4-J1OT5xNWUKn5hZNwjN7aJn
    random-1.1-9LLJAJa4iQFLJiLXBOBXBV
abi-depends: test-framework-0.8.2.0-DhLbYTIlvP2DU0cHcKcIVn=d1efc953df9f0f5d7a2c271019506a2e
             QuickCheck-2.11.3-58QsvdIMmwDDNaUIIDmLAr=59a035869ce3bae16d8c8360447f600f
             base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             extensible-exceptions-0.1.1.4-J1OT5xNWUKn5hZNwjN7aJn=56f3bc3a884a715c9ac7be8507078b91
             random-1.1-9LLJAJa4iQFLJiLXBOBXBV=2cade9e72fa19fe7a43e5ace84505d9f
haddock-interfaces: /usr/share/doc/haskell-test-framework-quickcheck2/html/test-framework-quickcheck2.haddock
haddock-html: /usr/share/doc/haskell-test-framework-quickcheck2/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-test-framework-quickcheck2-0.3.0.5-2-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-test-framework-quickcheck2.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: test-framework-quickcheck2
version: 0.3.0.5
id: test-framework-quickcheck2-0.3.0.5-HOPuSahD2LU2AFVRjsBcKR
key: test-framework-quickcheck2-0.3.0.5-HOPuSahD2LU2AFVRjsBcKR
license: BSD-3-Clause
maintainer: Haskell Libraries <libraries@haskell.org>
author: Max Bolingbroke <batterseapower@hotmail.com>
homepage: http://haskell.github.io/test-framework/
synopsis: QuickCheck-2 support for the test-framework package.
description:
    Allows @QuickCheck-2@ properties to be used with the </package/test-framework test-framework package>.
category: Testing
abi: 4500d7893d601963e358f7ca09ce1d18
exposed: True
exposed-modules:
    Test.Framework.Providers.QuickCheck2
import-dirs: /usr/lib/ghc-8.4.3/site-local/test-framework-quickcheck2-0.3.0.5
library-dirs: /usr/lib/ghc-8.4.3/site-local/test-framework-quickcheck2-0.3.0.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/test-framework-quickcheck2-0.3.0.5
hs-libraries: HStest-framework-quickcheck2-0.3.0.5-HOPuSahD2LU2AFVRjsBcKR
depends:
    test-framework-0.8.2.0-Goo1lQ5v8lSKQXzKjc8cO4
    QuickCheck-2.11.3-58QsvdIMmwDDNaUIIDmLAr base-4.11.1.0
    extensible-exceptions-0.1.1.4-J1OT5xNWUKn5hZNwjN7aJn
    random-1.1-9LLJAJa4iQFLJiLXBOBXBV
abi-depends: test-framework-0.8.2.0-Goo1lQ5v8lSKQXzKjc8cO4=64a691e8d693925c03bbca87367ae847
             QuickCheck-2.11.3-58QsvdIMmwDDNaUIIDmLAr=59a035869ce3bae16d8c8360447f600f
             base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             extensible-exceptions-0.1.1.4-J1OT5xNWUKn5hZNwjN7aJn=56f3bc3a884a715c9ac7be8507078b91
             random-1.1-9LLJAJa4iQFLJiLXBOBXBV=2cade9e72fa19fe7a43e5ace84505d9f
haddock-interfaces: /usr/share/doc/haskell-test-framework-quickcheck2/html/test-framework-quickcheck2.haddock
haddock-html: /usr/share/doc/haskell-test-framework-quickcheck2/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
